# monkey_color

[![PyPI version](https://badge.fury.io/py/monkey_color.svg)](https://badge.fury.io/py/monkey_color)

## 安裝說明

使用`pip`或其他 PyPi 軟件包進行安裝

```
pip install monkey_color
```

## monkey_color 的打印功能

您可以試試：

```python
from color import color


print(color("[rgb(255, 0, 0)]hello[yellow]red[ansi(blue)]blue[ansi(56)]test[/]"))
```

![Hello World](/github/print.png)